# pocketKnife

- A collection of useful functions for any data scientist working with NLP.
- Containes TF-IDF, embedders, and data cleaning functions


### reference
- https://towardsdatascience.com/create-your-own-python-package-and-publish-it-into-pypi-9306a29bc116




```bash
# install requirements
python -m pip install --upgrade setuptools twine
# upgrade pip version [GUI]
# delete old files [CLI]
# create new build [CLI]

# upload new build
```